"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var http_status_codes_1 = __importDefault(require("http-status-codes"));
var apiGatewayResponseBuilder_1 = require("./api-gateway/apiGatewayResponseBuilder");
__export(require("./api-gateway/apiGatewayResponseBuilder"));
var buildApiGatewayResponse = function (statusCode, body, cors, headers, isBase64Enconded) {
    if (cors === void 0) { cors = true; }
    var builder = new apiGatewayResponseBuilder_1.ApiGatewayResponseBuilder(statusCode, body);
    if (cors) {
        builder.withCors();
    }
    if (headers) {
        builder.withHeaders(headers);
    }
    if (isBase64Enconded) {
        builder.withBase64Encoding();
    }
    return builder.build();
};
exports.buildApiGatewayOkResponse = function (body, cors, headers, isBase64Encoded) {
    return buildApiGatewayResponse(http_status_codes_1.default.OK, body, cors, headers, isBase64Encoded);
};
exports.buildApiGatewayCreatedResponse = function (body, cors) {
    return buildApiGatewayResponse(http_status_codes_1.default.CREATED, body, cors);
};
exports.buildApiGatewayAcceptedResponse = function (body, cors) {
    return buildApiGatewayResponse(http_status_codes_1.default.ACCEPTED, body, cors);
};
exports.buildApiGatewayBadRequest = function (body, cors) {
    return buildApiGatewayResponse(http_status_codes_1.default.BAD_REQUEST, body, cors);
};
exports.buildApiGatewayUnauthorized = function (body, cors) {
    return buildApiGatewayResponse(http_status_codes_1.default.UNAUTHORIZED, body, cors);
};
exports.buildApiGatewayNotFound = function (body, cors) {
    return buildApiGatewayResponse(http_status_codes_1.default.NOT_FOUND, body, cors);
};
exports.buildApiGatewayServerFailure = function (body, cors) {
    return buildApiGatewayResponse(http_status_codes_1.default.INTERNAL_SERVER_ERROR, body, cors);
};
exports.buildApiGatewayCustomStatusCode = function (statusCode, body, cors) {
    return buildApiGatewayResponse(statusCode, body, cors);
};
